package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysAchievement;

public interface ISysAchievementService
{
    public SysAchievement selectSysAchievementById(Long id);

    public List<SysAchievement> selectSysAchievementList(SysAchievement sysAchievement);

    public int insertSysAchievement(SysAchievement sysAchievement);

    public int updateSysAchievement(SysAchievement sysAchievement);

    public int deleteSysAchievementByIds(Long[] ids);

    public int deleteSysAchievementById(Long id);
}
