package com.ruoyi.web.controller.achievement;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysAchievement;
import com.ruoyi.system.service.ISysAchievementService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/achievement")
public class SysAchievementController extends BaseController
{
    @Autowired
    private ISysAchievementService sysAchievementService;

    @PreAuthorize("@ss.hasPermi('achievement:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysAchievement sysAchievement)
    {
        startPage();
        List<SysAchievement> list = sysAchievementService.selectSysAchievementList(sysAchievement);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('achievement:export')")
    @Log(title = "产出成果", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysAchievement sysAchievement)
    {
        List<SysAchievement> list = sysAchievementService.selectSysAchievementList(sysAchievement);
        ExcelUtil<SysAchievement> util = new ExcelUtil<SysAchievement>(SysAchievement.class);
        util.exportExcel(response, list, "产出成果数据");
    }

    @PreAuthorize("@ss.hasPermi('achievement:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysAchievementService.selectSysAchievementById(id));
    }

    @PreAuthorize("@ss.hasPermi('achievement:add')")
    @Log(title = "产出成果", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysAchievement sysAchievement)
    {
        return toAjax(sysAchievementService.insertSysAchievement(sysAchievement));
    }

    @PreAuthorize("@ss.hasPermi('achievement:edit')")
    @Log(title = "产出成果", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysAchievement sysAchievement)
    {
        return toAjax(sysAchievementService.updateSysAchievement(sysAchievement));
    }

    @PreAuthorize("@ss.hasPermi('achievement:remove')")
    @Log(title = "产出成果", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysAchievementService.deleteSysAchievementByIds(ids));
    }
}
